@@ -16,7 +16,4 @@
 # limitations under the License.
 """
 SAR and Optical products
-
-.. include:: ../../documentation/optical.md
-.. include:: ../../documentation/sar.md
 """
