@@ -26,6 +26,9 @@ import rasterio
 from cloudpathlib import CloudPath
 from rasterio import crs as riocrs
 from rasterio.enums import Resampling
+from sertit import misc, rasters, strings
+from sertit.rasters import XDS_TYPE
+from sertit.snap import MAX_CORES
 
 from eoreader.bands import index
 from eoreader.bands.alias import (
@@ -42,9 +45,6 @@ from eoreader.bands.bands import OpticalBands
 from eoreader.exceptions import InvalidBandError, InvalidIndexError
 from eoreader.products.product import Product, SensorType
 from eoreader.utils import EOREADER_NAME
-from sertit import misc, rasters, strings
-from sertit.rasters import XDS_TYPE
-from sertit.snap import MAX_CORES
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -78,7 +78,7 @@ class OpticalProduct(Product):
         """
         return obn.GREEN
 
-    def get_default_band_path(self) -> str:
+    def get_default_band_path(self) -> Union[CloudPath, Path]:
         """
         Get default band (`GREEN` for optical data) path.
 
@@ -91,7 +91,7 @@ class OpticalProduct(Product):
             'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B03.jp2'
 
         Returns:
-            str: Default band path
+            Union[CloudPath, Path]: Default band path
         """
         default_band = self.get_default_band()
         return self.get_band_paths([default_band])[default_band]
@@ -227,9 +227,13 @@ class OpticalProduct(Product):
                 )
 
                 # Write on disk
-                rasters.write(
-                    band_arrays[band].rename(f"{to_str(band)[0]} CLEAN"), clean_band
-                )
+                try:
+                    rasters.write(
+                        band_arrays[band].rename(f"{to_str(band)[0]} CLEAN"), clean_band
+                    )
+                except Exception:
+                    # Not important if we cannot write it
+                    pass
 
         return band_arrays
 
@@ -496,7 +500,7 @@ class OpticalProduct(Product):
         """
         if resolution is not None:
             if isinstance(resolution, (list, tuple)):
-                res_str = "_".join(str([round(resolution, 2)])) + "m"
+                res_str = "_".join([str(round(res, 2)) for res in resolution]) + "m"
             else:
                 res_str = f"{resolution:.2f}m"
         else:
